@@ -4,5 +4,6 @@ from pydantic.dataclasses import dataclass
 
 @dataclass
 class EnterpriseExtension:
-    manager: Manager
     cost_center: str = None
+    manager: Manager = None
+    country_or_residence: str = None
