@@ -5,4 +5,4 @@ from pydantic.dataclasses import dataclass
 class Document:
     name: str
     document_url: str
-    download_url: str
+    download_url: str = None
